@@ -76,9 +76,10 @@ enum swErrorCode
     SW_ERROR_AIO_BAD_REQUEST   = 4001,
 
     /**
-     * Client
+     * Client & Socket
      */
     SW_ERROR_CLIENT_NO_CONNECTION = 5001,
+    SW_ERROR_SOCKET_CLOSED,
 
     SW_ERROR_SOCKS5_UNSUPPORT_VERSION = 7001,
     SW_ERROR_SOCKS5_UNSUPPORT_METHOD,
@@ -115,7 +116,10 @@ enum swErrorCode
     /**
      * Coroutine
      */
-    SW_ERROR_CO_MUTEX_DOUBLE_UNLOCK = 10001,
+    SW_ERROR_CO_OUT_OF_COROUTINE = 10001,
+    SW_ERROR_CO_HAS_BEEN_BOUND,
+
+    SW_ERROR_CO_MUTEX_DOUBLE_UNLOCK,
     SW_ERROR_CO_BLOCK_OBJECT_LOCKED,
     SW_ERROR_CO_BLOCK_OBJECT_WAITING,
     SW_ERROR_CO_YIELD_FAILED,
