@@ -108,6 +108,15 @@ enum swHttp2StreamType
         swHttp2FrameTraceLogFlags \
     );
 
+typedef struct
+{
+    uint32_t header_table_size;
+    uint32_t window_size;
+    uint32_t max_concurrent_streams;
+    uint32_t max_frame_size;
+    uint32_t max_header_list_size;
+} swHttp2_settings;
+
 /**
  +-----------------------------------------------+
  |                 Length (24)                   |
@@ -139,6 +148,15 @@ int swHttp2_send_setting_frame(swProtocol *protocol, swConnection *conn);
 char* swHttp2_get_type(int type);
 int swHttp2_get_type_color(int type);
 
+static sw_inline void swHttp2_init_settings(swHttp2_settings *settings)
+{
+    settings->header_table_size = SW_HTTP2_DEFAULT_HEADER_TABLE_SIZE;
+    settings->window_size = SW_HTTP2_DEFAULT_WINDOW_SIZE;
+    settings->max_concurrent_streams = SW_HTTP2_MAX_MAX_CONCURRENT_STREAMS;
+    settings->max_frame_size = SW_HTTP2_MAX_MAX_FRAME_SIZE;
+    settings->max_header_list_size = SW_HTTP2_MAX_MAX_HEADER_LIST_SIZE;
+}
+
 /**
  +-----------------------------------------------+
  |                 Length (24)                   |
