@@ -480,6 +480,10 @@ struct _swServer
      * asynchronous reloading
      */
     uint32_t reload_async :1;
+    /**
+     * asynchronous task worker
+     */
+    uint32_t task_async :1;
     /**
      * slowlog
      */
