@@ -37,6 +37,7 @@ extern "C" {
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
+#include <stddef.h>
 #include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -86,7 +87,7 @@ int daemon(int nochdir, int noclose);
 
 /*----------------------------------------------------------------------------*/
 
-#define SWOOLE_VERSION "4.2.5"
+#define SWOOLE_VERSION "4.2.7"
 #define SWOOLE_BUG_REPORT \
     "A bug occurred in Swoole-v" SWOOLE_VERSION ", please report it.\n"\
     "The Swoole developers probably don't know about it,\n"\
@@ -545,6 +546,7 @@ typedef struct _swConnection
      */
     uint8_t close_actively;
     uint8_t closed;
+    uint8_t close_queued;
     uint8_t closing;
     uint8_t close_reset;
     /**
@@ -816,7 +818,7 @@ typedef struct
 
 typedef void * (*swThreadStartFunc)(void *);
 typedef int (*swHandle)(swEventData *buf);
-typedef void (*swSignalHander)(int);
+typedef void (*swSignalHandler)(int);
 typedef struct _swReactor swReactor;
 
 typedef int (*swReactor_handle)(swReactor *reactor, swEvent *event);
@@ -1302,7 +1304,7 @@ int swoole_file_put_contents(char *filename, char *content, size_t length);
 long swoole_file_size(char *filename);
 void swoole_open_remote_debug(void);
 char *swoole_dec2hex(int value, int base);
-int swoole_version_compare(char *version1, char *version2);
+int swoole_version_compare(const char *version1, const char *version2);
 #ifdef HAVE_EXECINFO
 void swoole_print_trace(void);
 #endif
@@ -1339,7 +1341,7 @@ double swoole_microtime(void);
 void swoole_rtrim(char *str, int len);
 void swoole_redirect_stdout(int new_fd);
 #ifndef _WIN32
-int swoole_shell_exec(char *command, pid_t *pid);
+int swoole_shell_exec(char *command, pid_t *pid, uint8_t get_error_stream);
 #endif
 SW_API int swoole_add_function(const char *name, void* func);
 SW_API void* swoole_get_function(char *name, uint32_t length);
@@ -1379,6 +1381,7 @@ static sw_inline uint64_t swoole_ntoh64(uint64_t net)
 
 int swSocket_create(int type);
 int swSocket_bind(int sock, int type, char *host, int *port);
+int swSocket_accept(int fd, swSocketAddress *sa);
 int swSocket_wait(int fd, int timeout_ms, int events);
 int swSocket_wait_multi(int *list_of_fd, int n_fd, int timeout_ms, int events);
 void swSocket_clean(int fd);
@@ -1433,9 +1436,10 @@ static sw_inline int swSocket_tcp_nopush(int sock, int nopush)
 #define swSocket_tcp_nopush(sock, nopush)
 #endif
 
-swSignalHander swSignal_set(int sig, swSignalHander func, int restart, int mask);
-void swSignal_add(int signo, swSignalHander func);
+swSignalHandler swSignal_set(int sig, swSignalHandler func, int restart, int mask);
+void swSignal_add(int signo, swSignalHandler func);
 void swSignal_callback(int signo);
+swSignalHandler swSignal_get_handler(int signo);
 void swSignal_clear(void);
 void swSignal_none(void);
 
@@ -1463,6 +1467,7 @@ struct _swReactor
 
     uint32_t event_num;
     uint32_t max_event_num;
+    uint32_t signal_listener_num;
 
     uint32_t check_timer :1;
     uint32_t running :1;
@@ -1516,7 +1521,10 @@ struct _swReactor
     void (*free)(swReactor *);
 
     int (*setHandle)(swReactor *, int fdtype, swReactor_handle);
-    swDefer_callback *defer_tasks;
+
+    void *defer_tasks;
+    void (*do_defer_tasks)(swReactor *);
+
     swDefer_callback idle_task;
     swDefer_callback future_task;
 
@@ -1748,6 +1756,9 @@ int swReactor_create(swReactor *reactor, int max_event);
 int swReactor_setHandle(swReactor *, int, swReactor_handle);
 int swReactor_empty(swReactor *reactor);
 
+void swReactor_defer_task_create(swReactor *reactor);
+void swReactor_defer_task_destory(swReactor *reactor);
+
 static sw_inline swConnection* swReactor_get(swReactor *reactor, int fd)
 {
     if (reactor->thread)
@@ -2024,17 +2035,15 @@ enum swTimer_type
 struct _swTimer
 {
     /*--------------signal timer--------------*/
+    uint8_t initialized;
     swHeap *heap;
     swHashMap *map;
     int num;
-    int use_pipe;
     int lasttime;
-    int fd;
     uint64_t round;
     long _next_id;
     long _current_id;
     long _next_msec;
-    swPipe pipe;
     /*-----------------for EventTimer-------------------*/
     struct timeval basetime;
     /*--------------------------------------------------*/
@@ -2052,7 +2061,7 @@ static sw_inline swTimer_node* swTimer_get(swTimer *timer, long id)
     return (swTimer_node*) swHashMap_find_int(timer->map, id);
 }
 
-int swSystemTimer_init(int msec, int use_pipe);
+int swSystemTimer_init(int msec);
 void swSystemTimer_signal_handler(int sig);
 int swSystemTimer_event_handler(swReactor *reactor, swEvent *event);
 
@@ -2141,11 +2150,6 @@ typedef struct
     uint8_t dns_lookup_random :1;
     uint8_t use_async_resolver :1;
 
-    /**
-     * Timer used pipe
-     */
-    uint8_t use_timer_pipe :1;
-
     int error;
     int process_type;
     pid_t pid;
@@ -2244,6 +2248,30 @@ static sw_inline void sw_spinlock(sw_atomic_t *lock)
     }
 }
 
+static sw_inline int64_t swTimer_get_relative_msec()
+{
+    struct timeval now;
+    if (swTimer_now(&now) < 0)
+    {
+        return SW_ERR;
+    }
+    int64_t msec1 = (now.tv_sec - SwooleG.timer.basetime.tv_sec) * 1000;
+    int64_t msec2 = (now.tv_usec - SwooleG.timer.basetime.tv_usec) / 1000;
+    return msec1 + msec2;
+}
+
+static sw_inline int64_t swTimer_get_absolute_msec()
+{
+    struct timeval now;
+    if (swTimer_now(&now) < 0)
+    {
+        return SW_ERR;
+    }
+    int64_t msec1 = (now.tv_sec) * 1000;
+    int64_t msec2 = (now.tv_usec) / 1000;
+    return msec1 + msec2;
+}
+
 #ifdef __cplusplus
 }
 #endif
