@@ -35,7 +35,6 @@ static void swReactor_onTimeout_and_Finish(swReactor *reactor);
 static void swReactor_onTimeout(swReactor *reactor);
 static void swReactor_onFinish(swReactor *reactor);
 static void swReactor_onBegin(swReactor *reactor);
-static int swReactor_defer(swReactor *reactor, swCallback callback, void *data);
 
 int swReactor_create(swReactor *reactor, int max_event)
 {
@@ -60,8 +59,8 @@ int swReactor_create(swReactor *reactor, int max_event)
     reactor->onTimeout = swReactor_onTimeout;
 
     reactor->write = swReactor_write;
-    reactor->defer = swReactor_defer;
     reactor->close = swReactor_close;
+    swReactor_defer_task_create(reactor);
 
     reactor->socket_array = swArray_new(1024, sizeof(swConnection));
     if (!reactor->socket_array)
@@ -104,34 +103,6 @@ int swReactor_setHandle(swReactor *reactor, int _fdtype, swReactor_handle handle
     return SW_OK;
 }
 
-static void swReactor_defer_timer_callback(swTimer *timer, swTimer_node *tnode)
-{
-    swDefer_callback *cb = (swDefer_callback *) tnode->data;
-    cb->callback(cb->data);
-    sw_free(cb);
-}
-
-static int swReactor_defer(swReactor *reactor, swCallback callback, void *data)
-{
-    swDefer_callback *cb = sw_malloc(sizeof(swDefer_callback));
-    if (!cb)
-    {
-        swWarn("malloc(%ld) failed.", sizeof(swDefer_callback));
-        return SW_ERR;
-    }
-    cb->callback = callback;
-    cb->data = data;
-    if (unlikely(reactor->start == 0))
-    {
-        swTimer_add(&SwooleG.timer, 1, 0, cb, swReactor_defer_timer_callback);
-    }
-    else
-    {
-        LL_APPEND(reactor->defer_tasks, cb);
-    }
-    return SW_OK;
-}
-
 int swReactor_empty(swReactor *reactor)
 {
     //timer
@@ -140,14 +111,20 @@ int swReactor_empty(swReactor *reactor)
         return SW_FALSE;
     }
 
+    int event_num = reactor->event_num;
     int empty = SW_FALSE;
-    //thread pool
-    if (SwooleAIO.init && reactor->event_num == 1 && SwooleAIO.task_num == 0)
+    //aio thread pool
+    if (SwooleAIO.init && SwooleAIO.task_num == 0)
     {
-        empty = SW_TRUE;
+        event_num--;
+    }
+    //signalfd
+    if (swReactor_handle_isset(reactor, SW_FD_SIGNAL) && reactor->signal_listener_num == 0)
+    {
+        event_num--;
     }
     //no event
-    else if (reactor->event_num == 0)
+    if (event_num == 0)
     {
         empty = SW_TRUE;
     }
@@ -170,21 +147,7 @@ static void swReactor_onTimeout_and_Finish(swReactor *reactor)
         swTimer_select(&SwooleG.timer);
     }
     //defer tasks
-    do
-    {
-        swDefer_callback *defer_tasks = reactor->defer_tasks;
-        swDefer_callback *cb, *tmp;
-        reactor->defer_tasks = NULL;
-        LL_FOREACH(defer_tasks, cb)
-        {
-            cb->callback(cb->data);
-        }
-        LL_FOREACH_SAFE(defer_tasks, cb, tmp)
-        {
-            sw_free(cb);
-        }
-    } while (reactor->defer_tasks);
-
+    reactor->do_defer_tasks(reactor);
     //callback at the end
     if (reactor->idle_task.callback)
     {
