@@ -82,6 +82,11 @@ static void resume_php_stack(coro_task *task)
     swTraceLog(SW_TRACE_COROUTINE,"sw_coro_resume coro id %d", COROG.current_coro->cid);
     task->state = SW_CORO_RUNNING;
     EG(current_execute_data) = task->yield_execute_data;
+    /* set vm stack to global */
+    task->origin_stack = COROG.origin_vm_stack;
+    task->origin_vm_stack_top = COROG.origin_vm_stack_top;
+    task->origin_vm_stack_end = COROG.origin_vm_stack_end;
+    /* resume vm stack */
     EG(vm_stack) = task->yield_stack;
     EG(vm_stack_top) = task->yield_vm_stack_top;
     EG(vm_stack_end) = task->yield_vm_stack_end;
@@ -91,7 +96,6 @@ static void save_php_stack(coro_task *task)
 {
     swTraceLog(SW_TRACE_COROUTINE,"coro_yield coro id %d", task->cid);
     task->state = SW_CORO_YIELD;
-    task->is_yield = 1;
     /* save vm stack */
     task->yield_execute_data = EG(current_execute_data);
     task->yield_stack = EG(vm_stack);
@@ -103,6 +107,7 @@ static void save_php_stack(coro_task *task)
     EG(vm_stack_end) = task->origin_vm_stack_end;
     SW_RESUME_EG_SCOPE(task->execute_data->func->common.scope);
 }
+
 void internal_coro_resume(void *arg)
 {
     coro_task *task = (coro_task *)arg;
@@ -159,15 +164,17 @@ void coro_destroy(void)
 
 void sw_coro_check_bind(const char *name, int bind_cid)
 {
-    if (unlikely((bind_cid) > 0))
+    if (unlikely(bind_cid > 0))
     {
         swString *buffer = SwooleTG.buffer_stack;
-        sw_get_debug_print_backtrace(SwooleTG.buffer_stack, DEBUG_BACKTRACE_IGNORE_ARGS, 3);
-        swError(
+        sw_get_debug_print_backtrace(buffer, DEBUG_BACKTRACE_IGNORE_ARGS, 3);
+        swoole_error_log(
+            SW_LOG_ERROR, SW_ERROR_CO_HAS_BEEN_BOUND,
             "%s has already been bound to another coroutine #%d, "
             "reading or writing of the same socket in multiple coroutines at the same time is not allowed.\n"
             "%.*s", name, bind_cid, (int) buffer->length, buffer->str
         );
+        exit(255);
     }
 }
 
@@ -220,7 +227,9 @@ static void sw_coro_func(void *arg)
     }
     zend_init_execute_data(call, &func->op_array, retval);
 
+#ifdef SW_LOG_TRACE_OPEN
     task->cid = cid;
+#endif
     task->execute_data = call;
     task->stack = EG(vm_stack);
     task->vm_stack_top = EG(vm_stack_top);
@@ -228,9 +237,6 @@ static void sw_coro_func(void *arg)
     task->origin_stack = origin_vm_stack;
     task->origin_vm_stack_top = origin_vm_stack_top;
     task->origin_vm_stack_end = origin_vm_stack_end;
-    task->start_time = time(NULL);
-    task->function = NULL;
-    task->is_yield = 0;
     task->state = SW_CORO_RUNNING;
     task->co = coroutine_get_by_id(cid);
     coroutine_set_task(task->co, (void *)task);
@@ -269,8 +275,6 @@ int sw_coro_create(zend_fcall_info_cache *fci_cache, zval **argv, int argc, zval
     php_args.argv = argv;
     php_args.argc = argc;
     php_args.retval = retval;
-    php_args.post_callback = post_callback;
-    php_args.params = params;
 
     COROG.error = 0;
     COROG.coro_num++;
@@ -384,18 +388,9 @@ void sw_coro_close()
         swoole_call_hook(SW_GLOBAL_HOOK_ON_CORO_STOP, task);
     }
 
-    if (!task->is_yield)
-    {
-        EG(vm_stack) = task->origin_stack;
-        EG(vm_stack_top) = task->origin_vm_stack_top;
-        EG(vm_stack_end) = task->origin_vm_stack_end;
-    }
-    else
-    {
-        EG(vm_stack) = COROG.origin_vm_stack;
-        EG(vm_stack_top) = COROG.origin_vm_stack_top;
-        EG(vm_stack_end) = COROG.origin_vm_stack_end;
-    }
+    EG(vm_stack) = task->origin_stack;
+    EG(vm_stack_top) = task->origin_vm_stack_top;
+    EG(vm_stack_end) = task->origin_vm_stack_end;
     efree(task->stack);
     COROG.coro_num--;
     COROG.current_coro = NULL;
