@@ -122,14 +122,9 @@ static PHP_METHOD(swoole_server_port, set)
     HashTable *vht;
     zval *v;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &zset) == FAILURE)
-    {
-        return;
-    }
-    if (Z_TYPE_P(zset) != IS_ARRAY)
-    {
-        RETURN_FALSE;
-    }
+    ZEND_PARSE_PARAMETERS_START(1, 1)
+        Z_PARAM_ARRAY(zset)
+    ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     php_swoole_array_separate(zset);
     vht = Z_ARRVAL_P(zset);
@@ -237,7 +232,12 @@ static PHP_METHOD(swoole_server_port, set)
     {
         convert_to_string(v);
         port->protocol.package_eof_len = Z_STRLEN_P(v);
-        if (port->protocol.package_eof_len > SW_DATA_EOF_MAXLEN)
+        if (port->protocol.package_eof_len == 0)
+        {
+            swoole_php_fatal_error(E_ERROR, "pacakge_eof cannot be an empty string");
+            RETURN_FALSE;
+        }
+        else if (port->protocol.package_eof_len > SW_DATA_EOF_MAXLEN)
         {
             swoole_php_fatal_error(E_ERROR, "pacakge_eof max length is %d", SW_DATA_EOF_MAXLEN);
             RETURN_FALSE;
@@ -256,6 +256,11 @@ static PHP_METHOD(swoole_server_port, set)
     {
         convert_to_boolean(v);
         port->open_websocket_protocol = Z_BVAL_P(v);
+        if (port->open_websocket_protocol)
+        {
+            port->open_http_protocol = 1;
+            port->open_http2_protocol = 0;
+        }
     }
     if (php_swoole_array_get_value(vht, "websocket_subprotocol", v))
     {
@@ -521,7 +526,7 @@ static PHP_METHOD(swoole_server_port, set)
 static PHP_METHOD(swoole_server_port, on)
 {
     char *name = NULL;
-    zend_size_t len, i;
+    size_t len, i;
     zval *cb;
 
     swoole_server_port_property *property = swoole_get_property(getThis(), 0);
@@ -534,7 +539,7 @@ static PHP_METHOD(swoole_server_port, on)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &name, &len, &cb) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     char *func_name = NULL;
