@@ -39,11 +39,9 @@ define('IP_BAIDU', '180.97.33.107');
 
 /** ============= Proxy ============== */
 define('HTTP_PROXY_HOST', '127.0.0.1');
-if (IS_MAC_OS) {
-    define('HTTP_PROXY_PORT', 1087);
-} else {
-    define('HTTP_PROXY_PORT', 8888);
-}
+define('HTTP_PROXY_PORT', IS_MAC_OS ? 1087 : 8888);
+define('SOCKS5_PROXY_HOST', '127.0.0.1');
+define('SOCKS5_PROXY_PORT', IS_MAC_OS ? 1086 : 1080);
 
 /** ============== Files ============== */
 define('SOURCE_ROOT_PATH', __DIR__ . '/../../');
@@ -52,8 +50,9 @@ define('TEST_LOG_FILE', '/tmp/swoole.log');
 define('SSL_FILE_DIR', __DIR__ . '/api/swoole_http_server/localhost-ssl');
 
 /** ============== Times ============== */
-define('MAX_CONCURRENCY', IS_IN_TRAVIS ? 50 : 200);
-define('MAX_CONCURRENCY_MID', IS_IN_TRAVIS ? 35 : 100);
-define('MAX_CONCURRENCY_LOW', IS_IN_TRAVIS ? 20 : 50);
+define('MAX_CONCURRENCY', IS_IN_TRAVIS ? 64 : 256);
+define('MAX_CONCURRENCY_MID', IS_IN_TRAVIS ? 32 : 128);
+define('MAX_CONCURRENCY_LOW', IS_IN_TRAVIS ? 16 : 64);
 define('MAX_REQUESTS', IS_IN_TRAVIS ? 50 : 100);
-define('MAX_REQUESTS_LOW', IS_IN_TRAVIS ? 10 : 25);
\ No newline at end of file
+define('MAX_REQUESTS_LOW', IS_IN_TRAVIS ? 10 : 25);
+define('MAX_LOOPS', (IS_IN_TRAVIS ? 100 : 1000) * 1000);
\ No newline at end of file
